@@ -206,6 +206,8 @@ def voxel_count(dset,subbrick=0,p=None,positive_only=False,mask=None,ROI=None):
         cmd = ['3dROIstats','-1Dformat','-nomeanout','-nobriklab', '-nzvoxels']
         cmd += ['-mask',mask,dset]
         out = subprocess.check_output(cmd).split('\n')
+        if len(out)<4:
+            return 0
         rois = [int(x.replace('NZcount_','')) for x in out[1].strip()[1:].split()]
         counts = [int(x.replace('NZcount_','')) for x in out[3].strip().split()]
         count_dict = None
@@ -480,6 +482,62 @@ class Decon:
             for stim in stim_sds_list:
                 self.stim_sds[stim[1]] = float(stim[-1])
 
+def affine_align(dset_from,dset_to,skull_strip=True,mask=None,affine_suffix='_aff'):
+    ''' interface to 3dAllineate to align anatomies and EPIs
+    will align all of the datasets in the list ``epi_dsets`` to ``anatomy``'''
+    
+    dset_ss = lambda dset: os.path.split(suffix(dset,'_ns'))[1]
+    dset_u = lambda dset: os.path.split(suffix(dset,'_u'))[1]
+    def dset_source(dset):      
+        if skull_strip==True or skull_strip==dset:
+            return dset_ss(dset)
+        else:
+            return dset
+    
+    dset_affine = os.path.split(suffix(dset_from,affine_suffix))[1]
+    dset_affine_1D = prefix(dset_affine) + '.1D'
+        
+    if os.path.exists(dset_affine):
+        # final product already exists
+        return
+    
+    for dset in [dset_from,dset_to]:
+        if skull_strip==True or skull_strip==dset:
+            neural.fsl.skull_strip(dset,'_ns')
+        
+        neural.run([
+            '3dUnifize',
+            '-prefix', dset_u(dset_source(dset)),
+            '-input', dset_source(dset)
+        ],products=[dset_u(dset_source(dset))])
+    
+    mask_use = mask
+    if mask:
+        # the mask was probably made in the space of the original dset_to anatomy,
+        # which has now been cropped from the skull stripping. So the lesion mask
+        # needs to be resampled to match the corresponding mask
+        if skull_strip==True or skull_strip==dset_to:
+            neural.run(['3dresample','-master',dset_u(dset_ss(dset)),'-inset',mask,'-prefix',neural.afni.suffix(mask,'_resam')],products=neural.afni.suffix(mask,'_resam'))
+            mask_use = neural.afni.suffix(mask,'_resam')
+    
+    all_cmd = [
+        '3dAllineate',
+        '-prefix', dset_affine,
+        '-base', dset_u(dset_source(dset_to)),
+        '-source', dset_u(dset_source(dset_from)),
+        '-twopass',
+        '-cost', 'lpa',
+        '-1Dmatrix_save', dset_affine_1D,
+        '-autoweight',
+        '-cmass'
+    ]
+    
+    if mask:
+        all_cmd += ['-emask', mask_use]
+    
+    neural.run(all_cmd,products=dset_affine)
+    
+
 def qwarp_align(dset_from,dset_to,skull_strip=True,mask=None,affine_suffix='_aff',qwarp_suffix='_qwarp'):
     '''aligns ``dset_from`` to ``dset_to`` using 3dQwarp
     
@@ -529,43 +587,8 @@ def qwarp_align(dset_from,dset_to,skull_strip=True,mask=None,affine_suffix='_aff
         # final product already exists
         return
     
-    for dset in [dset_from,dset_to]:
-        if skull_strip==True or skull_strip==dset:
-            neural.fsl.skull_strip(dset,'_ns')
+    affine_align(dset_from,dset_to,skull_strip,mask,affine_suffix)
         
-        neural.run([
-            '3dUnifize',
-            '-prefix', dset_u(dset_source(dset)),
-            '-input', dset_source(dset)
-        ],products=[dset_u(dset_source(dset))])
-    
-    mask_use = mask
-    if mask:
-        # the mask was probably made in the space of the original dset_to anatomy,
-        # which has now been cropped from the skull stripping. So the lesion mask
-        # needs to be resampled to match the corresponding mask
-        if skull_strip==True or skull_strip==dset_to:
-            neural.run(['3dresample','-master',dset_u(dset_ss(dset)),'-inset',mask,'-prefix',neural.afni.suffix(mask,'_resam')],products=neural.afni.suffix(mask,'_resam'))
-            mask_use = neural.afni.suffix(mask,'_resam')
-    
-    all_cmd = [
-        '3dAllineate',
-        '-prefix', dset_affine,
-        '-base', dset_u(dset_source(dset_to)),
-        '-source', dset_u(dset_source(dset_from)),
-        '-twopass',
-        '-cost', 'lpa',
-        '-1Dmatrix_save', dset_affine_1D,
-        '-autoweight', 
-        '-fineblur', '3',
-        '-cmass'
-    ]
-    
-    if mask:
-        all_cmd += ['-emask', mask_use]
-    
-    neural.run(all_cmd,products=dset_affine)
-    
     warp_cmd = [
         '3dQwarp',
         '-prefix', dset_qwarp,
@@ -666,7 +689,8 @@ def align_epi_anat(anatomy,epi_dsets):
     for dset in ([anatomy] + epi_dsets):
         if is_nifti(dset):
             if dset!=anatomy:
-                nifti_copy(prefix(dset)+'_al+orig') 
+                dset_nifti = nifti_copy(prefix(dset)+'_al+orig')
+                nl.run(['gzip',dset_nifti])
             if dset==anatomy or os.path.exists(suffix(dset,'_al')):
                 for s in ['_al+orig.HEAD','_al+orig.BRIK*','+orig.HEAD','+orig.BRIK*']:
                     for d in glob.glob(prefix(dset) + s):
@@ -675,7 +699,7 @@ def align_epi_anat(anatomy,epi_dsets):
 
 def auto_polort(dset):
     '''a copy of 3dDeconvolve's ``-polort A`` option'''
-    info = dset_info(input_dset)
+    info = dset_info(dset)
     return 1 + round(info.reps/150.0)
 
 class AFNI_Censor_TooManyOutliers (RuntimeError):
